aboutsummaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorKitty Draper2011-03-05 23:43:19 -0500
committerKitty Draper2011-03-05 23:43:19 -0500
commit03b205db1b38d6c760c86af62606161bb8eecdda (patch)
tree3a8434318a3d681b579ef27ccab56cadf2428fc3 /source
parentd3aa3ee747d24cdcab513a55468bc57263504c7f (diff)
downloadsnes9x2005-03b205db1b38d6c760c86af62606161bb8eecdda.tar.gz
snes9x2005-03b205db1b38d6c760c86af62606161bb8eecdda.tar.bz2
snes9x2005-03b205db1b38d6c760c86af62606161bb8eecdda.zip
Fixed looking for BAGSFC directory
Diffstat (limited to 'source')
-rw-r--r--source/nds/gui.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/nds/gui.c b/source/nds/gui.c
index 8b8be4a..56ffc02 100644
--- a/source/nds/gui.c
+++ b/source/nds/gui.c
@@ -4515,29 +4515,29 @@ void gui_init(u32 lang_id)
ds2_setCPUclocklevel(11);
printf_clock();
//Find the "BAGSFC" system directory
DIR *current_dir;
- strcpy(main_path, "fat:/BAGSFC");
+ strcpy(main_path, "fat:/CATSFC");
current_dir = opendir(main_path);
if(current_dir)
closedir(current_dir);
else
{
- strcpy(main_path, "fat:/_SYSTEM/PLUGINS/BAGSFC");
+ strcpy(main_path, "fat:/_SYSTEM/PLUGINS/CATSFC");
current_dir = opendir(main_path);
if(current_dir)
closedir(current_dir);
else
{
strcpy(main_path, "fat:");
- if(search_dir("BAGSFC", main_path) == 0)
+ if(search_dir("CATSFC", main_path) == 0)
{
printf("Dirctory find: %s\n", main_path);
}
else
{
- err_msg(DOWN_SCREEN, "Can't fine BAGSFC directory, press any key to exit\n");
+ err_msg(DOWN_SCREEN, "Can't fine CATSFC directory, press any key to exit\n");
goto gui_init_err;
}
}
@@ -4515,29 +4515,29 @@ void gui_init(u32 lang_id)
ds2_setCPUclocklevel(11);
printf_clock();
- //Find the "BAGSFC" system directory
+ //Find the "CATSFC" system directory
DIR *current_dir;